from rich.console import Console
from rich.panel import Panel
from rich.text import Text
from rich.style import Style


class Banner:
    def __init__(self, library_name: str, library_version: str, subtext: str = ""):
        self.library_name = library_name
        self.library_version = library_version
        self.subtext = subtext
        self.console = Console()

        self._show()

    def _show(self):
        title = Text()
        title.append(
            f"{self.library_name}", style=Style(color="bright_magenta", bold=True)
        )
        title.append(
            f" v{self.library_version}", style=Style(color="bright_yellow", bold=True)
        )

        subtitle = Text(
            f"✨  {self.subtext}  ✨",
            style=Style(color="bright_cyan", italic=True, bold=True),
            justify="center",
        )

        panel = Panel(
            subtitle,
            title=title,
            border_style="bright_magenta",
            padding=(1, 4),
        )
        self.console.print(panel)



# Entry Point To Manimera
import warnings

warnings.filterwarnings("ignore", category=SyntaxWarning)

# External Libraries
from manim import *
from dotenv import load_dotenv

# Local Imports
from .terminal import Banner, Monitor

# Version
__version__ = "0.1.8"

# Set Environment
load_dotenv()

if __name__ != "__main__":
    Banner(
        library_name="Manimera",
        library_version=__version__,
        subtext="Mathematical visualization made simple by Senan",
    )
    Monitor()



import time
import atexit
import signal
from rich.console import Console
from rich.panel import Panel
from rich.text import Text


class Monitor:
    """
    Monitors total runtime and reports exit status.
    """

    def __init__(
        self,
        *,
        enabled: bool = True,
        console: Console | None = None,
        precision: int = 2,
    ):
        if not enabled:
            return

        self._start = time.perf_counter()
        self._interrupted = False
        self._precision = precision
        self._console = console or Console()

        signal.signal(signal.SIGINT, self._handle_sigint)
        atexit.register(self._handle_exit)

    def _handle_sigint(self, *_):
        self._interrupted = True
        raise KeyboardInterrupt

    def _handle_exit(self):
        elapsed = time.perf_counter() - self._start
        duration = f"{elapsed:.{self._precision}f}s"

        if self._interrupted:
            message = Text(
                f"⏹  Execution interrupted · {duration}",
                style="yellow",
                justify="center",
            )
            border = "yellow"
        else:
            message = Text(
                f"✔  Execution completed · {duration}",
                style="green",
                justify="center",
            )
            border = "green"

        panel = Panel(
            message,
            border_style=border,
            padding=(0, 2),
        )

        self._console.print(panel)
